summaryrefslogtreecommitdiff
path: root/head.S
diff options
context:
space:
mode:
authorAlek Du <alek.du@intel.com>2008-05-20 14:07:07 +0800
committerPatrick Tjin <pattjin@google.com>2014-07-21 20:22:36 -0700
commit6135ebb4d1a12902b2a74d6ed7f517bad8a694af (patch)
treef8bb692cfdc401570bff2549c770a68be90af2e7 /head.S
parent853e56be92357d033e3559a271cc6f96095120d0 (diff)
downloadbootstub-6135ebb4d1a12902b2a74d6ed7f517bad8a694af.tar.gz
* fixing stuff according to Rob: 1. no memsize 2. main ==> bootstub
Diffstat (limited to 'head.S')
-rw-r--r--head.S10
1 files changed, 4 insertions, 6 deletions
diff --git a/head.S b/head.S
index e242d48..177a94a 100644
--- a/head.S
+++ b/head.S
@@ -18,12 +18,10 @@
* 0x101000 +-----------------------+
* | free space |
* | used as stack |
- * 0x10010c +-----------------------+
- * | initrd size | MIC need to fill it according to bzImage size
* 0x100108 +-----------------------+
- * | bzImage size | MIC need to fill it according to initrd size
+ * | initrd size | MIC need to fill it according to bzImage size
* 0x100104 +-----------------------+
- * | mem size | MIC need to fill it
+ * | bzImage size | MIC need to fill it according to initrd size
* 0x100100 +-----------------------+
* | kernel cmdline | MIC need to fill it
* 0x100000 +-----------------------+
@@ -41,10 +39,10 @@ _start:
cli
/* setup stack, because we are heading off to "C" */
movl $STACK_OFFSET, %esp
/* after call main, GDT was set (0x10 and 0x18) IDT was clear
* eax will store 32bit entry of bzImage
*/
- calll main
+ calll bootstub
/* DS=ES=FS=GS=10 */
movl $__BOOT_DS, %ebx
movl %ebx, %ds
@@ -41,10 +39,10 @@ _start:
/* setup stack, because we are heading off to "C" */
movl $STACK_OFFSET, %esp
- /* after call main, GDT was set (0x10 and 0x18) IDT was clear
+ /* after call bootstub, GDT was set (0x10 and 0x18) IDT was clear
* eax will store 32bit entry of bzImage
*/